var webpublicationActionEventName = 'WebPublicationAction';
var resolvedNamespace = null;
var isPublication = false;

window.addEventListener("touchmove", function (event) {
	if (event.scale && event.scale !== 1) {
		event.preventDefault();
	}
}, {
	passive: false
});

if (window.webpublicationNamespace) {
	isPublication = true;
	resolvedNamespace = window.webpublicationNamespace;
} else if (window.parent.webpublicationNamespace) {
	resolvedNamespace = window.parent.webpublicationNamespace;
	window.webpublicationNamespace = resolvedNamespace;
}

if (window !== window.parent) {
	// polyfill to create customEvents from a component inside a publication
	(function () {

		if (typeof window.CustomEvent === 'function') return false;

		function CustomEvent(event, params) {
			params = params || {
				bubbles: false,
				cancelable: false,
				detail: undefined
			};
			var evt = document.createEvent('CustomEvent');
			evt.initCustomEvent(event, params.bubbles, params.cancelable, params.detail);
			return evt;
		}

		CustomEvent.prototype = window.Event.prototype;

		window.CustomEvent = CustomEvent;
	})();

	// if we are in an iframe we are probably in a component inside a publication, dispatch event to the parent publication
	document.addEventListener(webpublicationActionEventName, function (event) {
		try {
			window.parent.document.dispatchEvent(new CustomEvent(webpublicationActionEventName, event));
		} catch (error) {
			// we can't access parent frame, we probably are in an embedded publication
		}
	});
}

(function(ns) {
	var request = new XMLHttpRequest();
	ns.inddEpubDataExported = {
		isLoaded: false
	};

	if (!isPublication) {
		var configsJsonPath = 'script/configs.json';
		request.open('GET', configsJsonPath, false);
		request.onreadystatechange = function () {
			if (request.readyState === 4) {
				if (request.status === 200 || request.status == 0) {
					var configText = request.responseText;
					var config = JSON.parse(configText);
					var exportsNs = ns.inddEpubDataExported || {};
					exportsNs.config = exportsNs.config || config;
					exportsNs.isLoaded = true;

					var ResponsivePageManager = window.ResponsivePageManager;
					exportsNs.popupConfig = config;
					exportsNs.popupConfig.ResponsivePageManager = ResponsivePageManager;

					var initPageResponsive = function () {
						var containerElement = window.document.querySelector('body > div');
						var hasResponsiveClass = document.querySelector('.webpublication-responsive');

						if (containerElement === null || hasResponsiveClass === null) {
							window.requestAnimationFrame(initPageResponsive);
						} else {
							ResponsivePageManager.getResponsiveCssRules('css/responsiveElements.css')
								.then(function (cssRules) {
									var pageData = config.pagesData[0];
									var pageElement = containerElement.querySelector('#wpWrapper');
									var responsivePageManager = new ResponsivePageManager(pageElement, pageData.height, pageData.responsiveElements, cssRules);
									window.addEventListener('resize', responsivePageManager.onWindowResize.bind(responsivePageManager));
								}.bind(this));
						}
					};
					initPageResponsive();

					ns.inddEpubDataExported = exportsNs;
				}
			}
		}
		request.send(null);

		// resolve media params for embedded video/animations
		window.addEventListener('DOMContentLoaded', function () {
			var elementsWithSrc = document.querySelectorAll('[src]');
			var elementsWithSrcArray = Array.prototype.slice.call(elementsWithSrc);

			for (var i = 0; i < elementsWithSrcArray.length; i++) {
				var element = elementsWithSrcArray[i];
				var src = decodeURIComponent(element.src);

				if (hasMediaParam(src)) {
					resolveMediaParam(element);

					// reload video when resolve media param
					if (element.tagName === 'SOURCE') {
						element.parentElement.load();
					}
				}
			}

			function hasMediaParam(src) {
				var mediaParamRegex = /\$media\$|\${media}/;
				return !!src.match(mediaParamRegex);
			};

			function resolveMediaParam(element) {
				var regExp = /\d+\/\$media\$|\d+\/\${media}/;
				element.src = decodeURIComponent(element.src).replace(regExp, '');
			};
		});
	}

})(window.webpublicationNamespace || {});
